@@ -25,9 +25,6 @@ import time
 
 parser = argparse.ArgumentParser()
 parser.add_argument('-s', '--show', help='Persist showing counting time.')
-args = parser.parse_args()
-show = args.show
-
 
 class Constants:
     origin_date = datetime.datetime(1970, 1, 1, 0, 0)
@@ -60,7 +57,10 @@ class Date:
 
     def get_current_date(self, *args):
         if args:
-            self.date = datetime.datetime(*args)
+            if isinstance(args[0], datetime.datetime):
+                self.date = args[0]
+            else:
+                self.date = datetime.datetime(*args)
         else:
             self.date = datetime.datetime.utcnow()
         return self.date
@@ -108,14 +108,16 @@ class Date:
 
 detime = Date
 
-def counter(once=False):
 
-    if show == 'how':
+def counter():
+    args = parser.parse_args()
+
+    if args.show == 'how':
 
         while True:
             tm = time.gmtime()
             date = Date()
-            print("[{:04d}-{:02d}-{:02d} =] {} [= {:02d}:{:02d}:{:02d}]".format(
+            print("[{:05d}-{:02d}-{:02d} =] {} [= {:02d}:{:02d}:{:02d}]".format(
                 tm.tm_year, tm.tm_mon, tm.tm_mday, date, tm.tm_hour, tm.tm_min, tm.tm_sec
             ), end='\r', flush=True)
             del date
@@ -123,7 +125,7 @@ def counter(once=False):
     else:
         tm = time.gmtime()
         date = Date()
-        return date
+        print(date)
 
 
 if __name__ == '__main__':
